@@ -29,7 +29,6 @@
 #include "response.h"
 #include "scope.h"
 #include "handler/akappend.h"
-#include "handler/aklist.h"
 #include "handler/append.h"
 #include "handler/capability.h"
 #include "handler/copy.h"
@@ -45,10 +44,9 @@
 #include "handler/logout.h"
 #include "handler/modify.h"
 #include "handler/move.h"
-#include "handler/noop.h"
 #include "handler/remove.h"
-#include "handler/rename.h"
 #include "handler/resourceselect.h"
+#include "handler/search.h"
 #include "handler/searchpersistent.h"
 #include "handler/select.h"
 #include "handler/subscribe.h"
@@ -75,7 +73,7 @@ Handler::~Handler()
 
 Handler * Handler::findHandlerForCommandNonAuthenticated( const QByteArray & command )
 {
-    // allowed are LOGIN and AUTHENTICATE
+    // allowed are LOGIN
     if ( command == "LOGIN" )
         return new Login();
 
@@ -84,7 +82,7 @@ Handler * Handler::findHandlerForCommandNonAuthenticated( const QByteArray & com
 
 Handler * Handler::findHandlerForCommandAlwaysAllowed( const QByteArray & command )
 {
-    // allowed commands CAPABILITY, NOOP, and LOGOUT
+    // allowed commands CAPABILITY and LOGOUT
     if ( command == "LOGOUT" )
         return new Logout();
     if ( command == "CAPABILITY" )
@@ -105,33 +103,29 @@ QByteArray Handler::tag( ) const
 Handler * Handler::findHandlerForCommandAuthenticated( const QByteArray &_command, ImapStreamParser *streamParser )
 {
   QByteArray command( _command );
-  Scope::SelectionScope scope = Scope::None;
-
   // deal with command prefixes
-  if ( command == AKONADI_CMD_UID ) {
-    scope = Scope::Uid;
+  Scope::SelectionScope scope = Scope::selectionScopeFromByteArray( command );
+  if ( scope != Scope::None )
     command = streamParser->readString();
-  } else if ( command == AKONADI_CMD_RID ) {
-    scope = Scope::Rid;
-    command = streamParser->readString();
-  }
 
     // allowed commands are listed below ;-).
     if ( command == "APPEND" )
         return new Append();
     if ( command == AKONADI_CMD_COLLECTIONCREATE )
         return new Create( scope );
-    if ( command == "LIST" )
-        return new List();
+    if ( command == "LIST" || command == "X-AKLIST" ) //TODO: remove X-AKLIST support in Akonadi 2.0
+        return new List( scope, false );
+    if ( command == "LSUB" || command == "X-AKLSUB" ) //TODO: remove X-AKLSUB support in Akonadi 2.0
+        return new List( scope, true );
     if ( command == "SELECT" )
         return new Select( scope );
     if ( command == "SEARCH_STORE" )
         return new SearchPersistent();
-    if ( command == "NOOP" )
-        return new Noop();
+    if ( command == "SEARCH" )
+        return new Search();
     if ( command == AKONADI_CMD_ITEMFETCH )
         return new Fetch( scope );
-    if ( command == "EXPUNGE" )
+    if ( command == "EXPUNGE" ) //TODO: remove EXPUNGE support in Akonadi 2.0
         return new Expunge();
     if ( command == AKONADI_CMD_ITEMMODIFY )
         return new Store( scope );
@@ -141,8 +135,6 @@ Handler * Handler::findHandlerForCommandAuthenticated( const QByteArray &_comman
       return new Delete( scope );
     if ( command == AKONADI_CMD_COLLECTIONMODIFY )
       return new Modify( scope );
-    if ( command == "RENAME" )
-      return new Rename();
     if ( command == "BEGIN" )
       return new TransactionHandler( TransactionHandler::Begin );
     if ( command == "ROLLBACK" )
@@ -151,10 +143,6 @@ Handler * Handler::findHandlerForCommandAuthenticated( const QByteArray &_comman
       return new TransactionHandler( TransactionHandler::Commit );
     if ( command == AKONADI_CMD_ITEMCREATE )
       return new AkAppend();
-    if ( command == "X-AKLIST" )
-      return new AkList( scope, false );
-    if ( command == "X-AKLSUB" )
-      return new AkList( scope, true );
     if ( command == "SUBSCRIBE" )
       return new Subscribe( true );
     if ( command == "UNSUBSCRIBE" )
@@ -163,10 +151,10 @@ Handler * Handler::findHandlerForCommandAuthenticated( const QByteArray &_comman
       return new Copy();
     if ( command == AKONADI_CMD_COLLECTIONCOPY )
       return new ColCopy();
-    if ( command == "LINK" )
-      return new Link( true );
-    if ( command == "UNLINK" )
-      return new Link( false );
+    if ( command == AKONADI_CMD_ITEMLINK )
+      return new Link( scope, true );
+    if ( command == AKONADI_CMD_ITEMUNLINK )
+      return new Link( scope, false );
     if ( command == AKONADI_CMD_RESOURCESELECT )
       return new ResourceSelect();
     if ( command == AKONADI_CMD_ITEMDELETE )
